@@ -16,15 +16,15 @@ if [ "$ACTION" == "-i" ]; then
 
 	VERSIONOK=0
 	if [ $MAJOR -ge 1 ]; then
-		if [ $MINOR -ge 0 ]; then
-			if [ $RELEASE -ge 15 ]; then
+		if [ $MINOR -ge 2 ]; then
+			if [ $RELEASE -ge 1 ]; then
 				VERSIONOK=1
 			fi
 		fi
 	fi
 
 	if [ $VERSIONOK -ne 1 ]; then
-		echo "Version 1.0.15 of the native audit daemon is required in order"
+		echo "Version 1.2.1 of the native audit daemon is required in order"
 		echo "for snare to operate correctly. Please install this version"
 		echo "or later."
 		exit
@@ -32,20 +32,20 @@ if [ "$ACTION" == "-i" ]; then
 
 	$CONFDIR/init.d/auditd stop
 
-	if [ ! -f $CONFDIR/auditd.conf-snarebackup ]; then
-        	cp $CONFDIR/auditd.conf $CONFDIR/auditd.conf-snarebackup
+	if [ ! -f $CONFDIR/audit/auditd.conf-snarebackup ]; then
+        	cp $CONFDIR/audit/auditd.conf $CONFDIR/audit/auditd.conf-snarebackup
 	fi
 
 	if [ -f /usr/sbin/semodule ]; then
 		/usr/sbin/semodule -i snare.pp
 	fi
 
-	grep "^dispatcher" $CONFDIR/auditd.conf
+	grep "^dispatcher" $CONFDIR/audit/auditd.conf
         if [ $? -eq 0 ]; then
-                cat $CONFDIR/auditd.conf-snarebackup | sed 's/^dispatcher.*//' | egrep -v "^$" > $CONFDIR/auditd.conf
-                echo "dispatcher = $BINDIR/SnareDispatcher" >> $CONFDIR/auditd.conf;
+                cat $CONFDIR/audit/auditd.conf-snarebackup | sed 's/^dispatcher.*//' | egrep -v "^$" > $CONFDIR/audit/auditd.conf
+                echo "dispatcher = $BINDIR/SnareDispatcher" >> $CONFDIR/audit/auditd.conf;
         else
-                echo "dispatcher = $BINDIR/SnareDispatcher" >> $CONFDIR/auditd.conf;
+                echo "dispatcher = $BINDIR/SnareDispatcher" >> $CONFDIR/audit/auditd.conf;
         fi
 	$CONFDIR/init.d/auditd start
 	exit
@@ -54,13 +54,13 @@ fi
 if [ $1 == "-u" ]; then
 	# Uninstall
 	$CONFDIR/init.d/auditd stop
-	if [ -f $CONFDIR/auditd.conf-snarebackup ]; then
-                cat $CONFDIR/auditd.conf-snarebackup | egrep -v "^dispatcher = .*SnareDispatcher.*" > $CONFDIR/auditd.conf
-		rm -f $CONFDIR/auditd.conf-snarebackup
+	if [ -f $CONFDIR/audit/auditd.conf-snarebackup ]; then
+                cat $CONFDIR/audit/auditd.conf-snarebackup | egrep -v "^dispatcher = .*SnareDispatcher.*" > $CONFDIR/audit/auditd.conf
+		rm -f $CONFDIR/audit/auditd.conf-snarebackup
         else
-                cp $CONFDIR/auditd.conf $CONFDIR/auditd.conf-snarebackup
-                cat $CONFDIR/auditd.conf-snarebackup | egrep -v "^dispatcher" > $CONFDIR/auditd.conf
-                rm -f $CONFDIR/auditd.conf-snarebackup
+                cp $CONFDIR/audit/auditd.conf $CONFDIR/audit/auditd.conf-snarebackup
+                cat $CONFDIR/audit/auditd.conf-snarebackup | egrep -v "^dispatcher" > $CONFDIR/audit/auditd.conf
+                rm -f $CONFDIR/audit/auditd.conf-snarebackup
         fi
 
 	if [ -f /usr/sbin/semodule ]; then
