@@ -11,7 +11,17 @@ use Digest::MD5 qw(md5 md5_hex md5_base64);
 sub WebServerSetup() {
 	$port=shift;
 	$accesskey=shift;
-	$restrictip=shift;
+	$restrict=shift;
+	@restrictips=split(/,/,$restrict);
+	foreach $rest (@restrictips) {
+		if($rest !=~ /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/) {
+			# DNS name
+			$rsip=inet_ntoa(inet_aton($rest));
+		} else {
+			$rsip = $rest;
+		}
+		$restrictip{$rsip} = 1;
+	}
 
 	if(!$port) {
 		$port=6161;
@@ -21,6 +31,7 @@ sub WebServerSetup() {
 	$ppid=getppid();
 
 	$WEBCONTINUE=1;
+	$DNSTIMEOUT=120;
 
 	$SIG{QUIT}='WebTerminate';
 
@@ -46,6 +57,8 @@ sub WebServerSetup() {
 	$wrin = '';
 	vec($wrin,fileno(STDIN),1) = 1;
 
+	$dnsnow=time();
+	$dnslast=$dnsnow;
 	while($client=$server->accept()) {
 		if(!$WEBCONTINUE) { last; }
 		$client->autoflush(1);
@@ -59,11 +72,25 @@ sub WebServerSetup() {
 			$request.=$trequest . "\n";
 		}
 
-		if($restrictip) {
+		if($restrict) {
+			$dnsnow=time();
+			if ($dnsnow - $dnslast > $DNSTIMEOUT) {
+				$dnslast=$dnsnow;
+				%restrictip = ();
+				foreach $rest (@restrictips) {
+					if($rest !=~ /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/) {
+						# DNS name
+						$rsip=inet_ntoa(inet_aton($rest));
+					} else {
+						$rsip = $rest;
+					}
+					$restrictip{$rsip} = 1;
+				}
+			}
 			$sockaddr=$client->peername();
 			($port,$iaddr)=unpack_sockaddr_in($sockaddr);
 			$straddr=inet_ntoa($iaddr);
-			if($restrictip ne $straddr) {
+			if($restrictip{$straddr} != 1) {
 				# Not an authorised source.
 				HTMLHeader($client,"html");
 				print $client "<html><body>";
@@ -191,10 +218,23 @@ sub HandleWebPages() {
 				}
 				$count++;
 			}
+			delete($Config{"OUTPUT"}{"FILE"});
+			$count=0;
+			while(1) {
+				if(length($Arguments{"FileDestination-$count"}) != 0) {
+					$Config{"OUTPUT"}{"FILE"}{$count}=$Arguments{"FileDestination-$count"};
+				} else {
+					last;
+				}
+				$count++;
+			}
+
 			delete($Config{"CONFIG"});
 
+			$Config{"CONFIG"}{"CLIENTNAME"}=$Arguments{"NetworkClientName"};
 			$Config{"CONFIG"}{"USE_CRITICALITY"}=$Arguments{"NetworkUseCrit"};
 			$Config{"CONFIG"}{"SET_AUDIT"}=$Arguments{"NetworkSetAudit"};
+			#$Config{"CONFIG"}{"USE_REGEX"}=$Arguments{"NetworkUseRegex"};
 			$Config{"CONFIG"}{"SYSLOG_FACILITY"}=$Arguments{"NetworkSyslogFacility"};
 			$Config{"CONFIG"}{"SYSLOG_PRIORITY"}=$Arguments{"NetworkSyslogPriority"};
 
@@ -211,6 +251,8 @@ sub HandleWebPages() {
 
 		print $theclient "<center><table style=\"border: 1px solid black;\" width=\"70%\" border=0>\n";
 		$count=0;
+		print $theclient "<tr style=\"background: #ffffcc;\"><td>Override detected DNS Name with: </td>";
+		print $theclient "<td><input type=text name=NetworkClientName value=\"" . $Config{"CONFIG"}{"CLIENTNAME"} . "\"></td><td>&nbsp;</td></tr>";
 		foreach $element (keys(%{$Config{"OUTPUT"}{"NETWORK"}})) {
 			($dest,$port)=split(/:/,$Config{"OUTPUT"}{"NETWORK"}{$element});
 			if(!$port) { $port=6161; }
@@ -226,8 +268,15 @@ sub HandleWebPages() {
 		print $theclient "<option value=6161" . ($port!=514?" selected":"") . ">Snare - Port 6161</option>";
 		print $theclient "<option value=514 " . ($port==514?" selected ":"") . "style=\"color: green\">Syslog - Port 514</option>";
 		print $theclient "</select></div></td></tr>\n";
+		$count=0;
+		foreach $element (keys(%{$Config{"OUTPUT"}{"FILE"}})) {
+			print $theclient "<tr style=\"background: #ffffaa;\"><td>" . ($count?"":"Output File Name") . "</td><td><div align=center><input type=text name=FileDestination-$count size=25 value=\"" . $Config{"OUTPUT"}{"FILE"}{$element} . "\"></div></td><td>";
+			$count++;
+		}
+		print $theclient "<tr style=\"background: #ffffaa;\"><td>" . ($count?"":"Output File Name") . "</td><td><div align=center><input type=text name=FileDestination-$count size=25 value=\"\"></div></td><td>";
 		print $theclient "<tr style=\"background: #ffffcc;\"><td>Perform a scan of ALL objectives, and display the maximum criticality?<br><i>Slower event checks</i></td><td colspan=2><input type=checkbox name=NetworkUseCrit value=1" . ($Config{"CONFIG"}{"USE_CRITICALITY"}==1?" checked":"") . "></input></td></tr>\n";
 		print $theclient "<tr style=\"background: #ffffaa;\"><td>Allow SNARE to automatically set audit configuration</i></td><td colspan=2><input type=checkbox name=NetworkSetAudit value=1" . ($Config{"CONFIG"}{"SET_AUDIT"}==1?" checked":"") . "></input></td></tr>\n";
+		#print $theclient "<tr style=\"background: #ffffaa;\"><td>Use regular expressions in objectives</i></td><td colspan=2><input type=checkbox name=NetworkUseRegex value=1" . ($Config{"CONFIG"}{"USE_REGEX"}==1?" checked":"") . "></input></td></tr>\n";
 		print $theclient "<tr style=\"background: #ffffcc;\"><td>Syslog destination (if enabled)</td><td>";
 
 		$facility=$Config{"CONFIG"}{"SYSLOG_FACILITY"};
@@ -298,8 +347,8 @@ sub HandleWebPages() {
 			} else {
 				$Config{"REMOTE"}{"LISTEN_PORT"}="6161";
 			}
-			if($Arguments{"RemoteRestrictIP"} =~ /^[0-9a-zA-Z\.]+$/) {
-				$Config{"REMOTE"}{"RESTRICTIP"}=$Arguments{"RemoteRestrictIP"};
+			if($Arguments{"RemoteRestrictIP"} =~ /^[0-9a-zA-Z\.,]+$/) {
+				$Config{"REMOTE"}{"RESTRICT_IP"}=$Arguments{"RemoteRestrictIP"};
 			}
 			if(length($Arguments{"RemotePassword"})) {
 				if($Arguments{"RemotePassword"} ne $oldPassword) {
@@ -324,7 +373,7 @@ sub HandleWebPages() {
 		print $theclient "<tr style=\"background: #ffffaa;\"><td>Listen on port:</td>";
 		print $theclient "<td><input type=text name=RemotePort size=5 value=\"" . $Config{"REMOTE"}{"LISTEN_PORT"} . "\"></td></tr>";
 		print $theclient "<tr style=\"background: #ffffcc;\"><td>Only respond to requests from the IP address:</td>";
-		print $theclient "<td><input type=text name=RemoteRestrictIP value=\"" . $Config{"REMOTE"}{"RESTRICTIP"} . "\"></td></tr>";
+		print $theclient "<td><input type=text name=RemoteRestrictIP value=\"" . $Config{"REMOTE"}{"RESTRICT_IP"} . "\"></td></tr>";
 		print $theclient "<tr style=\"background: #ffffaa;\"><td>Require a password to connect:</td>";
 		print $theclient "<td><input type=password name=RemotePassword value=\"" . $Config{"REMOTE"}{"ACCESSKEY"} . "\"></td></tr>";
 		print $theclient "</table></center>\n";
@@ -385,7 +434,7 @@ sub HandleWebPages() {
 						$events=$NETWORK_EVENTS;
 					} elsif($eventselect =~ /^OTHER_EVENTS$/) {
 						# Does the events information look to be valid?
-						if($events !~ /^[a-z0-9,]+$/) {
+						if($events !~ /^[a-z0-9,_]+$/) {
 							# No. Fall back to process events.
 							print $theclient "<div align=center><div style=\"border: 1px solid black; background: #ccffcc; padding: 5px;\">Event list in objective $count was not valid. Using Process Events instead.</div></div><br><br>\n";
 							$events=$PROCESS_EVENTS;
@@ -780,8 +829,8 @@ sub HandleWebPages() {
 		print $theclient "[Remote]\n";
 		print $theclient "	Allow: " . $Config{"REMOTE"}{"ALLOW"} . "\n";
 		print $theclient "	WebPort: " . $Config{"REMOTE"}{"LISTEN_PORT"} . "\n";
-		print $theclient "	Restrict: " . $Config{"REMOTE"}{"RESTRICTIP"} . "\n";
-		print $theclient "	RestrictIP: " . $Config{"REMOTE"}{"RESTRICTIP"} . "\n";
+		print $theclient "	Restrict: " . $Config{"REMOTE"}{"RESTRICT_IP"} . "\n";
+		print $theclient "	RestrictIP: " . $Config{"REMOTE"}{"RESTRICT_IP"} . "\n";
 		print $theclient "	Password: " . ($Config{"REMOTE"}{"ACCESSKEY"}?"1":"0") . "\n\n";
 
 		print $theclient "[Output]\n";
@@ -792,11 +841,18 @@ sub HandleWebPages() {
 			print $theclient "	Network $count: $dest:$port\n";
 			$count++;
 		}
+		$count=0;
+		foreach $element (keys(%{$Config{"OUTPUT"}{"FILE"}})) {
+			print CONFIG "        file=" . $Config{"OUTPUT"}{"FILE"}{$element} . "\n";
+			$count++;
+		}
 		print $theclient "\n";
 
 		print $theclient "[Config]\n";
+		if(!$Config{"CONFIG"}{"CLIENTNAME"}) { print $theclient "	ClientName: " . $Config{"CONFIG"}{"CLIENTNAME"} . "\n"; }
 		print $theclient "	CritAudit: " . ($Config{"CONFIG"}{"USE_CRITICALITY"}?"1":"0") . "\n";
 		print $theclient "	Audit: " . ($Config{"CONFIG"}{"SET_AUDIT"}?"1":"0") . "\n";
+		#print $theclient "	Regex: " . ($Config{"CONFIG"}{"USE_REGEX"}?"1":"0") . "\n";
 		if(!$Config{"CONFIG"}{"SYSLOG_FACILITY"}) { $Config{"CONFIG"}{"SYSLOG_FACILITY"}="info"; }
 		if(!$Config{"CONFIG"}{"SYSLOG_PRIORITY"}) { $Config{"CONFIG"}{"SYSLOG_PRIORITY"}="local1"; }
 		print $theclient "	SyslogFacility: " . $Config{"CONFIG"}{"SYSLOG_FACILITY"} . "\n";
@@ -833,8 +889,8 @@ sub WriteConfig() {
 	print CONFIG "[Remote]\n";
 	print CONFIG "        allow=" . $Config{"REMOTE"}{"ALLOW"} . "\n";
 	print CONFIG "        listen_port=" . $Config{"REMOTE"}{"LISTEN_PORT"} . "\n";
-	if($Config{"REMOTE"}{"RESTRICTIP"}) {
-		print CONFIG "        restrict_ip=" . $Config{"REMOTE"}{"RESTRICTIP"} . "\n";
+	if($Config{"REMOTE"}{"RESTRICT_IP"}) {
+		print CONFIG "        restrict_ip=" . $Config{"REMOTE"}{"RESTRICT_IP"} . "\n";
 	}
 	if($Config{"REMOTE"}{"ACCESSKEY"}) {
 		print CONFIG "        accesskey=" . $Config{"REMOTE"}{"ACCESSKEY"} . "\n";
@@ -849,11 +905,17 @@ sub WriteConfig() {
 		print CONFIG "        network=$dest:$port\n";
 		$count++;
 	}
+	foreach $element (keys(%{$Config{"OUTPUT"}{"FILE"}})) {
+		print CONFIG "        file=" . $Config{"OUTPUT"}{"FILE"}{$element} . "\n";
+		$count++;
+	}
 
 	print CONFIG "\n";
 	print CONFIG "[Config]\n";
+	if($Config{"CONFIG"}{"CLIENTNAME"}) { print CONFIG "        clientname=" . $Config{"CONFIG"}{"CLIENTNAME"} . "\n"; }
 	print CONFIG "        use_criticality=" . ($Config{"CONFIG"}{"USE_CRITICALITY"}?"1":"0") . "\n";
 	print CONFIG "        set_audit=" . ($Config{"CONFIG"}{"SET_AUDIT"}?"1":"0") . "\n";
+	#print CONFIG "        use_regex=" . ($Config{"CONFIG"}{"USE_REGEX"}?"1":"0") . "\n";
 	if(!$Config{"CONFIG"}{"SYSLOG_FACILITY"}) { $Config{"CONFIG"}{"SYSLOG_FACILITY"}="info"; }
 	if(!$Config{"CONFIG"}{"SYSLOG_PRIORITY"}) { $Config{"CONFIG"}{"SYSLOG_PRIORITY"}="local1"; }
 	print CONFIG "        syslog_facility=" . $Config{"CONFIG"}{"SYSLOG_FACILITY"} . "\n";
